- Passing the `pos_label` and `sample_weight` parameters of
  :func:`metrics.confusion_matrix_at_thresholds` as positional arguments is deprecated
  and will be removed in v1.11.
  By :user:`Jérémie du Boisberranger <jeremiedbb>`.
